summaryrefslogtreecommitdiff
path: root/src/mongo/db/storage/wiredtiger/wiredtiger_customization_hooks.h
diff options
context:
space:
mode:
authorDaniel Gottlieb <daniel.gottlieb@10gen.com>2016-11-10 10:49:37 -0500
committerDaniel Gottlieb <daniel.gottlieb@10gen.com>2016-11-10 10:49:37 -0500
commit5ce001e6b364953c588d16410eb569939aa205ca (patch)
treee6b2beaab7f254c3d1514c23f3471f92281db5f5 /src/mongo/db/storage/wiredtiger/wiredtiger_customization_hooks.h
parent5ab5efc9b17be8a4ecebf845c9e07c0f15a67e0e (diff)
downloadmongo-5ce001e6b364953c588d16410eb569939aa205ca.tar.gz
SERVER-26646: Add structure that allows multiple WT extensions to be declared.
Diffstat (limited to 'src/mongo/db/storage/wiredtiger/wiredtiger_customization_hooks.h')
-rw-r--r--src/mongo/db/storage/wiredtiger/wiredtiger_customization_hooks.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/mongo/db/storage/wiredtiger/wiredtiger_customization_hooks.h b/src/mongo/db/storage/wiredtiger/wiredtiger_customization_hooks.h
index b604fb70c9c..e78995481bd 100644
--- a/src/mongo/db/storage/wiredtiger/wiredtiger_customization_hooks.h
+++ b/src/mongo/db/storage/wiredtiger/wiredtiger_customization_hooks.h
@@ -69,10 +69,10 @@ public:
virtual bool restartRequired() = 0;
/**
* Gets the WiredTiger encryption configuration string for the
* provided table name
*/
- virtual std::string getOpenConfig(StringData tableName) = 0;
+ virtual std::string getTableCreateConfig(StringData tableName) = 0;
/**
* Returns the maximum size addition when doing transforming temp data.
@@ -113,7 +113,7 @@ public:
bool restartRequired() override;
- std::string getOpenConfig(StringData tableName) override;
+ std::string getTableCreateConfig(StringData tableName) override;
std::unique_ptr<DataProtector> getDataProtector() override;
@@ -69,10 +69,10 @@ public:
virtual bool restartRequired() = 0;
/**
- * Gets the WiredTiger encryption configuration string for the
- * provided table name
+ * Gets an additional configuration string for the provided table name on a
+ * `WT_SESSION::create` call.
*/